SubmitPostDataBuilder

Struct SubmitPostDataBuilder 

pub struct SubmitPostDataBuilder {
    pub public_key: Option<String>,
    pub parent_post_hash_hex: Option<String>,
    pub body: Option<String>,
    pub image_urls: Option<Vec<String>>,
    pub video_urls: Option<Vec<String>>,
    pub fee_rate: Option<u64>,
    pub is_hidden: Option<bool>,
    pub extra_data: Option<HashMap<String, String>>,
}
Builder for building a submit post data

Fields

public_key: Option<String>

Public key of the user making a new post, editing a post, or making a comment

parent_post_hash_hex: Option<String>

Only used if making a comment. The post hash hex of the post your commenting on.

body: Option<String>

The body of your post

image_urls: Option<Vec<String>>

Any and all images for the post

video_urls: Option<Vec<String>>

Any and all videos for the post

fee_rate: Option<u64>

Min fee rate nanos per kb, defaults to 1250

is_hidden: Option<bool>

Used to “delete” a post, defaults to false

extra_data: Option<HashMap<String, String>>

An optional map of any meta data for the post

Implementations

Source

impl SubmitPostDataBuilder

pub fn new() -> Self

pub fn public_key(self, public_key: String) -> Self

Public key of the user making a new post, editing a post, or making a comment

pub fn parent_post_hash_hex(self, post_hash_hex: String) -> Self

Only used if making a comment. The post hash hex of the post your commenting on.

pub fn body(self, body: String) -> Self

The body of your post

pub fn image_urls(self, image_urls: Vec<String>) -> Self

Any and all images for the post

pub fn video_urls(self, video_urls: Vec<String>) -> Self

Any and all videos for the post

pub fn fee_rate(self, fee_rate: u64) -> Self

Min fee rate nanos per kb, defaults to 1250

pub fn is_hidden(self, is_hidden: bool) -> Self

Used to “delete” a post, defaults to false

pub fn extra_data(self, extra_data: HashMap<String, String>) -> Self

An optional map of any meta data for the post

pub fn build(self) -> Result<SubmitPostData, DesoError>

Builds the SubmitPostData